@@ -346,6 +346,43 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             sort_modules=sort_modules,
         )
 
+    def update_algebraic_module_from_args(
+        self,
+        module_name: str,
+        function: Union[Callable[..., float], Callable[..., Iterable[float]]]
+        | None = None,
+        derived_compounds: List[str] | None = None,
+        args: List[str] | None = None,
+        check_consistency: bool = True,
+        sort_modules: bool  = True,
+    ) -> None:
+        if args is None:
+            compounds = self.algebraic_modules[module_name].compounds
+            modifiers = self.algebraic_modules[module_name].modifiers
+            parameters = self.algebraic_modules[module_name].parameters
+        else:
+            compounds = []
+            modifiers = []
+            parameters = []
+            for i in args:
+                if i in self.parameters:
+                    parameters.append(i)
+                elif i in self.compounds:
+                    compounds.append(i)
+                else:
+                    modifiers.append(i)
+        self.update_algebraic_module(
+            module_name=module_name,
+            function=function,
+            compounds=compounds,
+            derived_compounds=derived_compounds,
+            modifiers=modifiers,
+            parameters=parameters,
+            args=args,
+            check_consistency=check_consistency,
+            sort_modules=sort_modules,
+        )
+
     def add_algebraic_modules(
         self, algebraic_modules: dict, meta_info: dict | None = None
     ) -> None:
@@ -430,18 +467,6 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         if sort_modules:
             self._sort_algebraic_modules()
 
-    def update_algebraic_module_from_args(
-        self,
-        module_name: str,
-        function: Union[Callable[..., float], Callable[..., Iterable[float]]]
-        | None = None,
-        derived_compounds: List[str] | None = None,
-        args: List[str] | None = None,
-        check_consistency: bool | None = None,
-        sort_modules: bool | None = None,
-    ) -> None:
-        raise NotImplementedError
-
     def update_algebraic_modules(self, modules: dict) -> None:
         """Update multiple algebraic modules
 
