@@ -133,7 +133,7 @@ class BaseModel(ABC):
                 self._ids.remove(id_)
             except KeyError:
                 warnings.warn(
-                    "Could not find id. Do you have duplicate ids in the model?"
+                    f"Could not find id '{id_}'. Do you have duplicate ids in the model?"
                 )
 
     def update_meta_info(self, component: str, meta_info: dict) -> None:
