@@ -7,14 +7,13 @@ __all__ = [
 from abc import ABC, abstractmethod
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-import numpy as np
-import numpy.typing as npt
+from ...typing import Array, ArrayLike
 
 
 class AbstractIntegrator(ABC):
     """Interface for integrators"""
 
-    def __init__(self, rhs: Callable, y0: Union[npt.NDArray[np.float64], List[float]]) -> None:
+    def __init__(self, rhs: Callable, y0: Union[Array, ArrayLike]) -> None:
         self.kwargs: Dict[str, Any] = {}
         self.rhs = rhs
         self.y0 = y0
@@ -30,9 +29,9 @@ class AbstractIntegrator(ABC):
         *,
         t_end: Optional[float] = None,
         steps: Optional[int] = None,
-        time_points: Optional[List[float]] = None,
+        time_points: Optional[ArrayLike] = None,
         **integrator_kwargs: Dict[str, Any],
-    ) -> Tuple[Optional[List[float]], Optional[List[float]]]:
+    ) -> Tuple[Optional[ArrayLike], Optional[ArrayLike]]:
         ...
 
     @abstractmethod
@@ -42,7 +41,7 @@ class AbstractIntegrator(ABC):
         tolerance: float,
         integrator_kwargs: Dict[str, Any],
         simulation_kwargs: Dict[str, Any],
-    ) -> Tuple[Optional[List[float]], Optional[List[float]]]:
+    ) -> Tuple[Optional[ArrayLike], Optional[ArrayLike]]:
         ...
 
     @abstractmethod
