@@ -511,6 +511,31 @@ class Model(_AbstractRateModel, BaseModel):
         for rate_name in rate_names:
             self.remove_reaction(rate_name=rate_name)
 
+    ##########################################################################
+    # Conversion functions
+    ##########################################################################
+
+    def make_parameter_dynamic(self, name: str) -> None:
+        if name in self.derived_parameters:
+            self.remove_derived_parameter(parameter_name=name)
+        else:
+            self.remove_parameter(parameter_name=name)
+        self.add_compound(name)
+
+        # Change all modifiers / parameters etc. accordingly
+        for rate_name, rate in self.rates.items():
+            if name in rate.args:
+                self.update_reaction_from_args(rate_name=rate_name, args=rate.args)
+
+    def make_compound_static(self, name: str, parameter_value: float) -> None:
+        self.remove_compound(name)
+        self.add_parameter(parameter_name=name, parameter_value=parameter_value)
+
+        # Change all modifiers / parameters etc. accordingly
+        for rate_name, rate in self.rates.items():
+            if name in rate.args:
+                self.update_reaction_from_args(rate_name=rate_name, args=rate.args)
+
     ##########################################################################
     # Simulation functions
     ##########################################################################
